@@ -1,11 +1,13 @@
 import os
 
 # to prevent the webdriver manager from polluting logs
-os.environ["WDM_LOG_LEVEL"] = "0"
+os.environ["WDM_LOG"] = "0"
 
 import json
+import logging
 import requests
 import sys
+from typing import Union
 
 from fake_useragent import UserAgent
 from selenium import webdriver
@@ -14,6 +16,9 @@ from webdriver_manager.chrome import ChromeDriverManager
 from discogs_alert import scrape as da_scrape, types as da_types
 
 
+logger = logging.getLogger(__name__)
+
+
 class Client:
     """API Client to interact with discogs server. Taken & modified from https://github.com/joalla/discogs_client."""
 
@@ -37,7 +42,7 @@ class Client:
     def _get(self, url: str, is_api: bool = True):
         response_content, status_code = self._request("GET", url, headers=None)
         if status_code != 200:
-            print(f"ERROR: status_code: {status_code}, content: {response_content}")
+            logger.info(f"ERROR: status_code: {status_code}, content: {response_content}")
             return False
         return json.loads(response_content) if is_api else response_content
 
@@ -66,9 +71,9 @@ class Client:
         release_dict = self._get(f"{self._base_url}/releases/{release_id}")
         return da_types.Release(**release_dict)
 
-    def get_release_stats(self, release_id: int) -> da_types.ReleaseStats:
+    def get_release_stats(self, release_id: int) -> Union[da_types.ReleaseStats, bool]:
         release_stats_dict = self._get(f"{self._base_url}/marketplace/stats/{release_id}")
-        return da_types.ReleaseStats(**release_stats_dict)
+        return da_types.ReleaseStats(**release_stats_dict) if isinstance(release_stats_dict, dict) else False
 
     def get_wantlist(self, username: str):
         # TODO: add entities to deserialise this correctly
